package com.ruoyi.app.service;

import com.ruoyi.app.model.HookRegister;
import com.ruoyi.app.model.request.ReqHookRegister;

import java.util.List;

/**
 * 吊钩注册Service接口
 *
 * @author coede
 * @date 2025-03-19
 */
public interface IHookRegisterService
{
    /**
     * 查询吊钩注册
     *
     * @param id 吊钩注册主键
     * @return 吊钩注册
     */
    public HookRegister selectHookRegisterById(Long id);

    /**
     * 根据芯片编号查询吊钩号
     *
     * @param epcNo 芯片编号
     * @return 参数键值
     */
    public String selectHookNoByEpcNo(String epcNo);

    /**
     * 查询吊钩注册列表
     *
     * @param req 吊钩注册
     * @return 吊钩注册集合
     */
    public List<HookRegister> selectHookRegisterList(ReqHookRegister req);

    /**
     * 校验吊钩编号是否唯一
     *
     * @param  hookRegister 吊钩注册
     * @return 结果
     */
    public boolean checkHookNoUnique(HookRegister hookRegister);

    /**
     * 校验芯片编号是否唯一
     *
     * @param  hookRegister 吊钩注册
     * @return 结果
     */
    public boolean checkEpcNoUnique(HookRegister hookRegister);

    /**
     * 新增吊钩注册
     *
     * @param hookRegister 吊钩注册
     * @return 结果
     */
    public int insertHookRegister(HookRegister hookRegister);

    /**
     * 修改吊钩注册
     *
     * @param hookRegister 吊钩注册
     * @return 结果
     */
    public int updateHookRegister(HookRegister hookRegister);

    /**
     * 批量删除吊钩注册
     *
     * @param ids 需要删除的吊钩注册主键集合
     * @return 结果
     */
    public int deleteHookRegisterByIds(Long[] ids);

    /**
     * 删除吊钩注册信息
     *
     * @param id 吊钩注册主键
     * @return 结果
     */
    public int deleteHookRegisterById(Long id);

    /**
     * 加载参数缓存数据
     */
    public void loadingConfigCache();

    /**
     * 清空参数缓存数据
     */
    public void clearConfigCache();

    /**
     * 重置参数缓存数据
     */
    public void resetConfigCache();
}
